@@ -23,9 +23,7 @@
 
 #------------------------------------------------------------------------------------------
 """
-Downloads specified ''study'' data from ''cloud''. 
-This is one of the basic data exchange utility. 
-Usually appears in context of ''[[cloudflu-study-upload]]'' utility.
+This script is responsible for efficient downloading of multi file data
 """
 
 
@@ -110,14 +108,10 @@ def download_file( the_file_object, the_output_dir, the_number_threads, the_remo
 
     import os.path; an_output_dir = os.path.join( the_output_dir, a_file_dirname )
     print_d( "an_output_dir = '%s'\n" % an_output_dir, a_printing_depth + 1 )
-
-    from cloudflu.common.archivators import get_archivator
-    an_api_version = the_file_object.api_version()
-    an_archivator = get_archivator( an_api_version )
     
     import os.path; a_file_path = os.path.join( an_output_dir, a_file_basename )
     if the_fresh :
-        sh_command( "rm -fr '%s.%s*'" % ( a_file_path, an_archivator.suffix() ), a_printing_depth + 1 )
+        sh_command( "rm -fr '%s.tgz*'" % ( a_file_path ), a_printing_depth + 1 )
         sh_command( "rm -fr '%s'" % ( a_file_path ), a_printing_depth + 1 )
         pass
 
@@ -126,13 +120,11 @@ def download_file( the_file_object, the_output_dir, the_number_threads, the_remo
         pass
 
     print_d( "a_file_path = '%s'\n" % a_file_path, a_printing_depth + 2 )
-    
     if not os.path.exists( a_file_path ) :
-
         while True :
             download_seeds( the_file_object, a_file_basename, an_output_dir, the_number_threads, a_printing_depth + 3 )
             
-            an_archive_name = "%s.%s" % ( a_file_basename, an_archivator.suffix() )
+            an_archive_name = "%s.tgz" % a_file_basename
             
             import os.path
             an_archive_path = os.path.join( an_output_dir, an_archive_name )
@@ -151,8 +143,7 @@ def download_file( the_file_object, the_output_dir, the_number_threads, the_remo
             import os; os.remove( an_archive_path )
             pass
         
-        an_archivator.unpack( an_archive_path, an_output_dir, a_printing_depth + 1 )
-        #sh_command( "tar -xzf '%s' -C '%s'" % ( an_archive_path, an_output_dir ), a_printing_depth + 1 )
+        sh_command( "tar -xzf '%s' -C '%s'" % ( an_archive_path, an_output_dir ), a_printing_depth + 1 )
         
         sh_command( "cd '%s' && rm %s-*" % ( an_output_dir, an_archive_name ), a_printing_depth + 1 )
         
@@ -173,13 +164,9 @@ def download_file( the_file_object, the_output_dir, the_number_threads, the_remo
 
 
 #------------------------------------------------------------------------------------------
-def download_files( the_study_object, the_output_dir, the_number_threads, the_socket_timeout,
-                    the_wait, the_remove, the_fresh, the_callback ) :
+def download_files( the_study_object, the_output_dir, the_number_threads, the_wait, the_remove, the_fresh, the_callback ) :
     a_worker_pool = TaggedWorkerPool( the_number_threads )
 
-    a_socket_timeout = the_socket_timeout * the_number_threads * the_number_threads
-    import socket; socket.setdefaulttimeout( a_socket_timeout )
-
     if the_wait == False or the_study_object.sealed() :
         for a_file_object in the_study_object :
             a_worker_pool.charge( a_file_object.located_file(), download_file, 
@@ -196,8 +183,7 @@ def download_files( the_study_object, the_output_dir, the_number_threads, the_so
 
             for a_file_object in the_study_object :
                 a_worker_pool.charge( a_file_object.located_file(), download_file, 
-                                      ( a_file_object, the_output_dir, the_number_threads, 
-                                        the_remove, the_fresh, the_callback ) )
+                                      ( a_file_object, the_output_dir, the_number_threads, the_remove, the_fresh, the_callback ) )
                 pass
 
             if an_sealed :
@@ -220,8 +206,8 @@ def download_files( the_study_object, the_output_dir, the_number_threads, the_so
 
 
 #--------------------------------------------------------------------------------------
-def file_entry_point( the_study_object, the_output_dir, the_number_threads,
-                      the_located_file, the_wait, the_remove, the_fresh, the_callback ) :
+def file_entry_point( the_study_object, the_output_dir, the_located_file, 
+                      the_number_threads, the_wait, the_remove, the_fresh, the_callback ) :
     if the_wait == False or the_study_object.sealed() :
         try:
             a_file_object = TFileObject.get( the_study_object, the_located_file )
@@ -258,8 +244,8 @@ def file_entry_point( the_study_object, the_output_dir, the_number_threads,
 
 
 #--------------------------------------------------------------------------------------
-def entry_point( the_study_object, the_output_dir, the_number_threads, the_socket_timeout, 
-                 the_located_files = None, the_wait = True, the_remove = False, the_fresh = False, the_callback = None ) :
+def entry_point( the_study_object, the_output_dir, the_located_files = None, 
+                 the_number_threads = 3, the_wait = True, the_remove = False, the_fresh = False, the_callback = None ) :
     a_spent_time = Timer()
     
     if the_output_dir == None :
@@ -268,18 +254,14 @@ def entry_point( the_study_object, the_output_dir, the_number_threads, the_socke
 
     if the_located_files == None :
         download_files( the_study_object, the_output_dir,
-                        the_number_threads, the_socket_timeout, 
-                        the_wait, the_remove, the_fresh, the_callback )
+                        the_number_threads, the_wait, the_remove, the_fresh, the_callback )
     else :
         a_worker_pool = TaggedWorkerPool( the_number_threads )
         
-        a_socket_timeout = the_socket_timeout * the_number_threads * the_number_threads
-        import socket; socket.setdefaulttimeout( a_socket_timeout )
-
         for a_located_file in the_located_files :
             a_worker_pool.charge( a_located_file, file_entry_point, 
-                                  ( the_study_object, the_output_dir, the_number_threads, 
-                                    a_located_file, the_wait, the_remove, the_fresh, the_callback ) )
+                                  ( the_study_object, the_output_dir, a_located_file, 
+                                    the_number_threads, the_wait, the_remove, the_fresh, the_callback ) )
             pass
     
         a_worker_pool.shutdown()
@@ -330,7 +312,7 @@ def main() :
 
     common.options.extract( an_option_parser )
     
-    a_socket_timeout = common.communication_options.extract( an_option_parser )
+    common.communication_options.extract( an_option_parser )
 
     a_number_threads = common.concurrency_options.extract( an_option_parser )
 
@@ -365,8 +347,8 @@ def main() :
     
 
     print_i( "-------------------------- Running actual functionality -------------------------\n" )
-    a_study_object = entry_point( a_study_object, an_output_dir, a_number_threads, a_socket_timeout, 
-                                  a_located_files, a_wait, a_remove, a_fresh )
+    a_study_object = entry_point( a_study_object, an_output_dir, a_located_files, 
+                                  a_number_threads, a_wait, a_remove, a_fresh )
     
     print_i( "------------------- Printing succussive pipeline arguments ----------------------\n" )
     print a_study_name
